@@ -29,8 +29,6 @@ a normalization of the shortened keywords to their full version.
 """
 from __future__ import unicode_literals
 
-import re
-
 INSPIRE_PARSER_KEYWORDS = {
     # Abstract
     'abstract': 'abstract',
@@ -60,7 +58,6 @@ INSPIRE_PARSER_KEYWORDS = {
     # Bulletin
     'bb': 'reportnumber',
     'bull': 'reportnumber',
-    'eprint': 'reportnumber',
 
     # Cataloguer
     'cat': 'cataloguer',
@@ -119,6 +116,9 @@ INSPIRE_PARSER_KEYWORDS = {
     # DOI
     'doi': 'doi',
 
+    # ePrint
+    'eprint': 'eprint',
+
     # Exact-Author
     'exact-author': 'exact-author',
     'exactauthor': 'exact-author',
@@ -128,12 +128,6 @@ INSPIRE_PARSER_KEYWORDS = {
     'experiment': 'experiment',
     'exp': 'experiment',
 
-    # Field code
-    'field-code': 'field-code',
-    'subject': 'field-code',
-    'fc': 'field-code',
-    'f': 'field-code',
-
     # First-Author
     'first-author': 'first-author',
     'firstauthor': 'first-author',
@@ -199,6 +193,9 @@ INSPIRE_PARSER_KEYWORDS = {
     'rn': 'reportnumber',
     'r': 'reportnumber',
 
+    # Subject
+    'subject': 'subject',
+
     # Title
     'title': 'title',
     'ti': 'title',
@@ -237,3 +234,8 @@ DATE_SPECIFIERS_COLLECTION = (
     DATE_THIS_MONTH_REGEX_PATTERN,
     DATE_LAST_MONTH_REGEX_PATTERN
 )
+# #####
+
+ES_MUST_QUERY = "must"
+ES_SHOULD_QUERY = "should"
+DEFAULT_ES_OPERATOR_FOR_MALFORMED_QUERIES = ES_MUST_QUERY
